@@ -6,10 +6,12 @@ from .vectorizer import Vectorizer
 from .fitter import Fitter
 from .counter import Counter
 from .tfidfer import Tfidfer
+from .bm25er import Bm25er
 from .searcher import Searcher
 from .variator import Variator
 from .abstractor import Abstractor
 from .questioner import Questioner
 from .summarizer import Summarizer
 from .answerer import Answerer
+from .identifier import Identifier
 from .handler import Handler
\ No newline at end of file
