@@ -15,7 +15,7 @@ def levenshtein_distance(s1, s2):
 class Measurer(t2t.Tokenizer):
 
   def transform(self, input_lines, src_lang='en', metric='levenshtein_distance', **kwargs):
-    t2t.Transformer.transform(self, input_lines, src_lang=src_lang, **kwargs)
+    input_lines = t2t.Transformer.transform(self, input_lines, src_lang=src_lang, **kwargs)
     tokenizer = self.__class__.tokenizer
     tokenizer.src_lang = src_lang
     input_lines = list(zip(*[l.split(" [SEP] ") for l in input_lines]))
